@@ -76,6 +76,7 @@ static constexpr AirspaceClassStringCouple airspace_class_strings[] = {
   { _T("F"), CLASSF },
   { _T("TMZ"), TMZ },
   { _T("G"), CLASSG },
+  { _T("RMZ"), RMZ },
 };
 
 static constexpr AirspaceClassCharCouple airspace_tnp_class_chars[] = {
@@ -108,6 +109,7 @@ static constexpr AirspaceClassStringCouple airspace_tnp_type_strings[] = {
   { _T("CYD"), DANGER },
   { _T("CYA"), CLASSF },
   { _T("MATZ"), MATZ },
+  { _T("RMZ"), RMZ },
 };
 
 // this can now be called multiple times to load several airspaces.
@@ -143,6 +145,7 @@ struct TempAirspaceType
     days_of_operation.SetAll();
     radio = _T("");
     type = OTHER;
+    base = top = AirspaceAltitude();
     points.clear();
     center.longitude = Angle::Zero();
     center.latitude = Angle::Zero();
@@ -326,6 +329,9 @@ ReadAltitude(const TCHAR *buffer, AirspaceAltitude &altitude)
   case FL:
     altitude.reference = AltitudeReference::STD;
     altitude.flight_level = value;
+
+    /* prepare fallback, just in case we have no terrain */
+    altitude.altitude = Units::ToSysUnit(value, Unit::FLIGHT_LEVEL);
     return;
 
   case UNLIMITED:
@@ -336,6 +342,9 @@ ReadAltitude(const TCHAR *buffer, AirspaceAltitude &altitude)
   case SFC:
     altitude.reference = AltitudeReference::AGL;
     altitude.altitude_above_terrain = fixed(-1);
+
+    /* prepare fallback, just in case we have no terrain */
+    altitude.altitude = fixed(0);
     return;
 
   default:
@@ -353,11 +362,17 @@ ReadAltitude(const TCHAR *buffer, AirspaceAltitude &altitude)
   case AGL:
     altitude.reference = AltitudeReference::AGL;
     altitude.altitude_above_terrain = value;
+
+    /* prepare fallback, just in case we have no terrain */
+    altitude.altitude = value;
     return;
 
   case STD:
     altitude.reference = AltitudeReference::STD;
     altitude.flight_level = Units::ToUserUnit(value, Unit::FLIGHT_LEVEL);
+
+    /* prepare fallback, just in case we have no QNH */
+    altitude.altitude = value;
     return;
 
   default:
@@ -498,7 +513,7 @@ static AirspaceClass
 ParseType(const TCHAR *buffer)
 {
   for (unsigned i = 0; i < ARRAY_SIZE(airspace_class_strings); i++)
-    if (StringAfterPrefix(buffer, airspace_class_strings[i].string))
+    if (StringIsEqualIgnoreCase(buffer, airspace_class_strings[i].string))
       return airspace_class_strings[i].type;
 
   return OTHER;
