@@ -104,24 +104,19 @@ WindEKFGlue::Update(const NMEAInfo &basic, const DerivedInfo &derived)
   ResetBlackout();
 
   fixed V = basic.true_airspeed;
-  fixed dynamic_pressure = sqr(V);
   float gps_vel[2];
   const auto sc = basic.track.SinCos();
   const fixed gps_east = sc.first, gps_north = sc.second;
   gps_vel[0] = (float)(gps_east * basic.ground_speed);
   gps_vel[1] = (float)(gps_north * basic.ground_speed);
 
-  float dT = 1.0;
-
   if (reset_pending) {
     /* do the postponed WindEKF reset */
     reset_pending = false;
     ekf.Init();
   }
 
-  ekf.StatePrediction(gps_vel, dT);
-  ekf.Correction(dynamic_pressure, gps_vel);
-  // CovariancePrediction(dT);
+  ekf.Update(V, gps_vel);
 
   ++i;
   if (i % 10 != 0)
