@@ -27,6 +27,8 @@ Copyright_License {
 #include "Dialogs/Message.hpp"
 #include "Widget/RowFormWidget.hpp"
 #include "Look/DialogLook.hpp"
+#include "Look/GlobalFonts.hpp"
+#include "Look/FontSettings.hpp"
 #include "Form/Form.hpp"
 #include "Form/Util.hpp"
 #include "Form/Frame.hpp"
@@ -46,21 +48,12 @@ Copyright_License {
 #include "Language/Language.hpp"
 #include "Compiler.h"
 
-#ifdef ENABLE_OPENGL
-#include "Screen/OpenGL/Cache.hpp"
+#ifdef HAVE_TEXT_CACHE
+#include "Screen/Custom/Cache.hpp"
 #endif
 
 #include <assert.h>
 
-extern LOGFONT log_infobox;
-extern LOGFONT log_title;
-extern LOGFONT log_map;
-extern LOGFONT log_infobox_small;
-extern LOGFONT log_map_bold;
-extern LOGFONT log_cdi;
-extern LOGFONT log_map_label;
-extern LOGFONT log_map_label_important;
-
 static bool changed = false;
 
 class FontPreviewAndButton : public NullWidget, private ActionListener {
@@ -121,7 +114,7 @@ private:
       custom = defaults;
 
     if (font.Load(custom)) {
-#ifdef ENABLE_OPENGL
+#ifdef HAVE_TEXT_CACHE
       TextCache::Flush();
 #endif
       preview.SetFont(font);
@@ -144,7 +137,7 @@ public:
     ButtonWindowStyle button_style;
     button_style.Hide();
     button_style.TabStop();
-    button = new WndButton(parent, UIGlobals::GetDialogLook(),
+    button = new WndButton(parent, UIGlobals::GetDialogLook().button,
                            _("Edit"), rc, button_style, *this, 0);
 
     TextWindowStyle preview_style;
@@ -209,19 +202,23 @@ static const struct {
   const TCHAR *text;
   const LOGFONT &defaults;
 } customisable_fonts[] = {
-  { ProfileKeys::FontTitleWindowFont, N_("InfoBox titles"), log_title },
-  { ProfileKeys::FontInfoWindowFont, N_("InfoBox values, normal"),
-    log_infobox },
-  { ProfileKeys::FontTitleSmallWindowFont, N_("InfoBox values, small"),
-    log_infobox_small },
-  { ProfileKeys::FontMapWindowFont, N_("Waypoint labels"), log_map },
+  { ProfileKeys::DialogFont, N_("Dialog text"),
+    Fonts::default_settings.dialog },
+  { ProfileKeys::FontTitleWindowFont, N_("InfoBox titles"),
+    Fonts::default_settings.title },
+  { ProfileKeys::FontInfoWindowFont, N_("InfoBox values"),
+    Fonts::default_settings.infobox },
+  { ProfileKeys::FontMapWindowFont, N_("Waypoint labels"),
+    Fonts::default_settings.map },
   { ProfileKeys::FontMapLabelFont, N_("Topography labels, normal"),
-    log_map_label },
+    Fonts::default_settings.map_label },
   { ProfileKeys::FontMapLabelImportantFont,
     N_("Topography labels, important"),
-    log_map_label_important},
-  { ProfileKeys::FontMapWindowBoldFont, N_("Dialog text"), log_map_bold },
-  { ProfileKeys::FontCDIWindowFont, N_("Gauges"), log_cdi },
+    Fonts::default_settings.map_label_important},
+  { ProfileKeys::FontMapWindowBoldFont, N_("Overlay text"),
+    Fonts::default_settings.map_bold },
+  { ProfileKeys::FontCDIWindowFont, N_("Gauges"),
+    Fonts::default_settings.cdi },
   { nullptr, nullptr, *(const LOGFONT *)nullptr }
 };
 
