@@ -33,17 +33,17 @@ UnorderedTask::UnorderedTask(const TaskType _type,
 {
 }
 
-
-bool 
+bool
 UnorderedTask::CalcBestMC(const AircraftState &aircraft,
                           const GlidePolar &glide_polar,
                           fixed& best) const
 {
   TaskPoint *tp = GetActiveTaskPoint();
-  if (!tp) {
+  if (tp == nullptr || !aircraft.location.IsValid()) {
     best = glide_polar.GetMC();
     return false;
   }
+
   TaskBestMc bmc(tp, aircraft, task_behaviour.glide, glide_polar);
   return bmc.search(glide_polar.GetMC(), best);
 }
@@ -69,28 +69,28 @@ UnorderedTask::CheckTransitions(const AircraftState &state_now,
   return false;
 }
 
-fixed 
+fixed
 UnorderedTask::CalcRequiredGlide(const AircraftState &aircraft,
                                  const GlidePolar &glide_polar) const
 {
   TaskPoint *tp = GetActiveTaskPoint();
-  if (!tp) {
+  if (tp == nullptr || !aircraft.location.IsValid())
     return fixed(0);
-  }
+
   TaskGlideRequired bgr(tp, aircraft, task_behaviour.glide, glide_polar);
   return bgr.search(fixed(0));
 }
 
 void
-UnorderedTask::GlideSolutionRemaining(const AircraftState &state, 
-                                        const GlidePolar &polar,
-                                        GlideResult &total,
-                                        GlideResult &leg)
+UnorderedTask::GlideSolutionRemaining(const AircraftState &state,
+                                      const GlidePolar &polar,
+                                      GlideResult &total,
+                                      GlideResult &leg)
 {
   GlideResult res;
 
   TaskPoint* tp = GetActiveTaskPoint();
-  if (tp) {
+  if (tp != nullptr && state.location.IsValid()) {
     res = TaskSolution::GlideSolutionRemaining(*tp, state,
                                                task_behaviour.glide, polar);
     res.CalcDeferred();
@@ -101,11 +101,11 @@ UnorderedTask::GlideSolutionRemaining(const AircraftState &state,
   leg = res;
 }
 
-void 
-UnorderedTask::GlideSolutionTravelled(const AircraftState &state, 
+void
+UnorderedTask::GlideSolutionTravelled(const AircraftState &state,
                                       const GlidePolar &glide_polar,
-                                        GlideResult &total,
-                                        GlideResult &leg)
+                                      GlideResult &total,
+                                      GlideResult &leg)
 {
   GlideResult null_res;
   null_res.Reset();
@@ -113,15 +113,15 @@ UnorderedTask::GlideSolutionTravelled(const AircraftState &state,
   leg = null_res;
 }
 
-void 
-UnorderedTask::GlideSolutionPlanned(const AircraftState &state, 
+void
+UnorderedTask::GlideSolutionPlanned(const AircraftState &state,
                                     const GlidePolar &glide_polar,
-                                      GlideResult &total,
-                                      GlideResult &leg,
-                                      DistanceStat &total_remaining_effective,
-                                      DistanceStat &leg_remaining_effective,
-                                      const GlideResult &solution_remaining_total,
-                                      const GlideResult &solution_remaining_leg)
+                                    GlideResult &total,
+                                    GlideResult &leg,
+                                    DistanceStat &total_remaining_effective,
+                                    DistanceStat &leg_remaining_effective,
+                                    const GlideResult &solution_remaining_total,
+                                    const GlideResult &solution_remaining_leg)
 {
   total = solution_remaining_total;
   leg = solution_remaining_leg;
@@ -137,31 +137,29 @@ UnorderedTask::GlideSolutionPlanned(const AircraftState &state,
     leg_remaining_effective.Reset();
 }
 
-
-
-fixed 
-UnorderedTask::ScanTotalStartTime(const AircraftState &state)
+fixed
+UnorderedTask::ScanTotalStartTime()
 {
-  return state.time;
+  return fixed(-1);
 }
 
-fixed 
-UnorderedTask::ScanLegStartTime(const AircraftState &state)
+fixed
+UnorderedTask::ScanLegStartTime()
 {
-  return state.time;
+  return fixed(-1);
 }
 
 
-void 
+void
 UnorderedTask::ScanDistanceMinMax(const GeoPoint &location, bool full,
-                                    fixed *dmin, fixed *dmax)
+                                  fixed *dmin, fixed *dmax)
 {
   *dmin = *dmax = stats.total.remaining.IsDefined()
     ? stats.total.remaining.GetDistance()
     : fixed(0);
 }
 
-fixed 
+fixed
 UnorderedTask::ScanDistanceNominal()
 {
   return stats.total.remaining.IsDefined()
@@ -177,29 +175,29 @@ UnorderedTask::ScanDistancePlanned()
     : fixed(0);
 }
 
-fixed 
+fixed
 UnorderedTask::ScanDistanceScored(const GeoPoint &location)
 {
   return fixed(0);
 }
 
-fixed 
+fixed
 UnorderedTask::ScanDistanceTravelled(const GeoPoint &location)
 {
   return fixed(0);
 }
 
-fixed 
+fixed
 UnorderedTask::ScanDistanceRemaining(const GeoPoint &location)
 {
   TaskPoint *tp = GetActiveTaskPoint();
-  if (!tp) {
+  if (tp == nullptr || !location.IsValid())
     return fixed(0);
-  }
+
   return tp->Distance(location);
 }
 
-fixed 
+fixed
 UnorderedTask::CalcGradient(const AircraftState &state) const
 {
   return CalcLegGradient(state);
