@@ -24,15 +24,7 @@ Copyright_License {
 #ifndef XCSOAR_EVENT_TIMER_HPP
 #define XCSOAR_EVENT_TIMER_HPP
 
-#if defined(ANDROID) || defined(USE_EGL)
 #include <atomic>
-#elif defined(ENABLE_SDL)
-#include <SDL_timer.h>
-#include <atomic>
-#else
-#include "Screen/Window.hpp"
-#include "Screen/Timer.hpp"
-#endif
 
 #include <assert.h>
 #include <stddef.h>
@@ -49,38 +41,15 @@ Copyright_License {
  * The class #WindowTimer is cheaper on WIN32; use it instead of this
  * class if you are implementing a #Window.
  */
-class Timer
-#ifdef USE_GDI
-  : private Window, private WindowTimer
-#endif
-{
-#if defined(ANDROID) || defined(USE_EGL)
+class Timer {
   std::atomic<bool> enabled, queued;
   unsigned ms;
-#elif defined(ENABLE_SDL)
-  SDL_TimerID id;
-
-  /**
-   * True when the timer event has been pushed to the event queue.
-   * This is used to prevent duplicate items stacking on the event
-   * queue.
-   */
-  std::atomic<bool> queued;
-#endif
 
 public:
   /**
    * Construct a Timer object that is not set initially.
    */
-#if defined(ANDROID) || defined(USE_EGL)
   Timer():enabled(false), queued(false) {}
-#elif defined(ENABLE_SDL)
-  Timer():id(NULL), queued(false) {}
-#else
-  Timer():WindowTimer(*(Window *)this) {
-    Window::CreateMessageWindow();
-  }
-#endif
 
   Timer(const Timer &other) = delete;
 
@@ -90,11 +59,7 @@ protected:
    * shall only be used by derived classes to pass inactive instances
    * around.
    */
-  Timer(Timer &&other)
-#ifdef USE_GDI
-    :WindowTimer(*(Window *)this)
-#endif
-  {
+  Timer(Timer &&other) {
     assert(!IsActive());
     assert(!other.IsActive());
   }
@@ -104,29 +69,18 @@ public:
     /* timer must be cleaned up explicitly */
     assert(!IsActive());
 
-#ifdef USE_EGL
+#if defined(USE_CONSOLE) || defined(NON_INTERACTIVE)
     assert(!queued.load(std::memory_order_relaxed));
     assert(!enabled.load(std::memory_order_relaxed));
 #endif
   }
 
-#ifdef USE_GDI
-  /* inherit WindowTimer's methods */
-  using WindowTimer::IsActive;
-  using WindowTimer::Schedule;
-  using WindowTimer::Cancel;
-#else
-
   /**
    * Is the timer active, i.e. is it waiting for the current period to
    * end?
    */
   bool IsActive() const {
-#if defined(ANDROID) || defined(USE_EGL)
     return enabled.load(std::memory_order_relaxed);
-#elif defined(ENABLE_SDL)
-    return id != NULL;
-#endif
   }
 
   /**
@@ -135,14 +89,18 @@ public:
    */
   void Schedule(unsigned ms);
 
+  /**
+   * Schedule the timer.  Preserves the previous setting if there was
+   * one.
+   */
+  void SchedulePreserve(unsigned ms);
+
   /**
    * Cancels the scheduled timer, if any.  This is safe to be called
    * while the timer is running.
    */
   void Cancel();
 
-#endif /* !GDI */
-
 protected:
   /**
    * This method gets called after the configured time has elapsed.
@@ -150,21 +108,8 @@ protected:
    */
   virtual void OnTimer() = 0;
 
-#if defined(ANDROID) || defined(USE_EGL)
 public:
   void Invoke();
-#elif defined(ENABLE_SDL)
-private:
-  void Invoke();
-  static void Invoke(void *ctx);
-
-  Uint32 Callback(Uint32 interval);
-  static Uint32 Callback(Uint32 interval, void *param);
-#else
-private:
-  /* virtual methods from class Window */
-  virtual bool OnTimer(WindowTimer &timer) override;
-#endif
 };
 
 #endif
