@@ -35,14 +35,6 @@ SubForm::FindByName(tstring::const_pointer name)
   return i->second;
 }
 
-void
-SubForm::FilterAdvanced(bool advanced)
-{
-  for (auto i = expert_windows.begin(), end = expert_windows.end();
-       i != end; ++i)
-    (*i)->SetVisible(advanced);
-}
-
 void
 SubForm::Clear()
 {
@@ -51,6 +43,5 @@ SubForm::Clear()
     delete *i;
 
   destruct_windows.clear();
-  expert_windows.clear();
   name_to_window.clear();
 }
