@@ -29,12 +29,9 @@ Copyright_License {
 #include "Renderer/ThermalBandRenderer.hpp"
 #include "Renderer/TaskProgressRenderer.hpp"
 #include "Formatter/UserUnits.hpp"
-#include "Units/Units.hpp"
 #include "Components.hpp"
 #include "Interface.hpp"
-#include "Blackboard/DeviceBlackboard.hpp"
 #include "Screen/Layout.hpp"
-#include "Protection.hpp"
 #include "UIGlobals.hpp"
 #include "Look/Look.hpp"
 #include "Computer/GlideComputer.hpp"
