@@ -76,6 +76,8 @@ struct PageLayout
 
     THERMAL_ASSISTANT,
 
+    HORIZON,
+
     /**
      * A dummy entry that is used for validating profile values.
      */
@@ -95,6 +97,12 @@ struct PageLayout
      */
     CROSS_SECTION,
 
+    /**
+     * A custom #Widget is being displayed.  This is not a
+     * user-accessible option, it's only used for runtime state.
+     */
+    CUSTOM,
+
     /**
      * A dummy entry that is used for validating profile values.
      */
