@@ -24,14 +24,11 @@ Copyright_License {
 */
 
 #include "PopupMessage.hpp"
-#include "Look/Fonts.hpp"
+#include "Look/GlobalFonts.hpp"
 #include "Screen/SingleWindow.hpp"
 #include "Screen/Layout.hpp"
 #include "Screen/Font.hpp"
-#include "LocalPath.hpp"
 #include "Audio/Sound.hpp"
-#include "LogFile.hpp"
-#include "Language/Language.hpp"
 #include "StatusMessage.hpp"
 #include "UISettings.hpp"
 #include "OS/Clock.hpp"
@@ -117,7 +114,7 @@ PopupMessage::Create(const PixelRect _rc)
 
   LargeTextWindow::Create(parent, GetRect(100), style);
 
-  SetFont(Fonts::map_bold);
+  SetFont(Fonts::dialog_bold);
   InstallWndProc();
 }
 
@@ -165,7 +162,7 @@ PopupMessage::UpdateTextAndLayout(const TCHAR *text)
   } else {
     SetText(text);
 
-    const UPixelScalar font_height = Fonts::map_bold.GetHeight();
+    const UPixelScalar font_height = Fonts::dialog_bold.GetHeight();
 
     unsigned n_lines = max(n_visible, max(1u, GetRowCount()));
 
