@@ -22,7 +22,7 @@ Copyright_License {
 */
 
 #include "AirspaceRenderer.hpp"
-#include "MapSettings.hpp"
+#include "AirspaceRendererSettings.hpp"
 #include "Projection/WindowProjection.hpp"
 #include "Screen/Canvas.hpp"
 #include "MapWindow/MapCanvas.hpp"
@@ -35,7 +35,7 @@ Copyright_License {
 #include "Airspace/AirspaceWarning.hpp"
 #include "Airspace/ProtectedAirspaceWarningManager.hpp"
 #include "Engine/Airspace/AirspaceWarningManager.hpp"
-#include "MapWindow/MapDrawHelper.hpp"
+#include "MapWindow/StencilMapCanvas.hpp"
 #include "Screen/Layout.hpp"
 #include "NMEA/Aircraft.hpp"
 
@@ -43,13 +43,23 @@ Copyright_License {
 #include "Screen/OpenGL/Scope.hpp"
 #endif
 
+#ifdef USE_GDI
+#include "Screen/GDI/AlphaBlend.hpp"
+#endif
+
 class AirspaceWarningCopy
 {
 private:
   StaticArray<const AbstractAirspace *,64> ids_inside, ids_warning, ids_acked;
   StaticArray<GeoPoint,32> locations;
 
+  unsigned serial;
+
 public:
+  unsigned GetSerial() const {
+    return serial;
+  }
+
   void Visit(const AirspaceWarning& as) {
     if (as.GetWarningState() == AirspaceWarning::WARNING_INSIDE) {
       ids_inside.checked_append(&as.GetAirspace());
@@ -63,6 +73,8 @@ public:
   }
 
   void Visit(const AirspaceWarningManager &awm) {
+    serial = awm.GetSerial();
+
     for (auto i = awm.begin(), end = awm.end(); i != end; ++i)
       Visit(*i);
   }
@@ -88,18 +100,6 @@ public:
     return as.IsActive() && Find(as, ids_inside);
   }
 
-  void VisitWarnings(AirspaceVisitor &visitor) const {
-    for (auto it = ids_warning.begin(), end = ids_warning.end(); it != end; ++it)
-      if (!IsAcked(**it))
-        visitor.Visit(**it);
-  }
-
-  void VisitInside(AirspaceVisitor &visitor) const {
-    for (auto it = ids_inside.begin(), end = ids_inside.end(); it != end; ++it)
-      if (!IsAcked(**it))
-        visitor.Visit(**it);
-  }
-
 private:
   bool Find(const AbstractAirspace& as,
             const StaticArray<const AbstractAirspace *,64> &list) const {
@@ -123,8 +123,8 @@ public:
 
   bool operator()(const AbstractAirspace& airspace) const {
     return visible_predicate(airspace) ||
-           warnings.IsInside(airspace) ||
-           warnings.HasWarning(airspace);
+      warnings.IsInside(airspace) ||
+      warnings.HasWarning(airspace);
   }
 };
 
@@ -157,30 +157,34 @@ public:
 
 private:
   void VisitCircle(const AirspaceCircle &airspace) {
+    const AirspaceClassRendererSettings &class_settings =
+      settings.classes[airspace.GetType()];
+    const AirspaceClassLook &class_look = look.classes[airspace.GetType()];
+
     RasterPoint screen_center = projection.GeoToScreen(airspace.GetCenter());
     unsigned screen_radius = projection.GeoToScreenDistance(airspace.GetRadius());
-    GLEnable stencil(GL_STENCIL_TEST);
 
     if (!warning_manager.IsAcked(airspace) &&
-        settings.classes[airspace.GetType()].fill_mode !=
+        class_settings.fill_mode !=
         AirspaceClassRendererSettings::FillMode::NONE) {
+      GLEnable stencil(GL_STENCIL_TEST);
       GLEnable blend(GL_BLEND);
       SetupInterior(airspace);
       if (warning_manager.HasWarning(airspace) ||
           warning_manager.IsInside(airspace) ||
           look.thick_pen.GetWidth() >= 2 * screen_radius ||
-          settings.classes[airspace.GetType()].fill_mode ==
+          class_settings.fill_mode ==
           AirspaceClassRendererSettings::FillMode::ALL) {
         // fill whole circle
         canvas.DrawCircle(screen_center.x, screen_center.y, screen_radius);
       } else {
         // draw a ring inside the circle
-        Color color = settings.classes[airspace.GetType()].fill_color;
+        Color color = class_look.fill_color;
         Pen pen_donut(look.thick_pen.GetWidth() / 2, color.WithAlpha(90));
         canvas.SelectHollowBrush();
         canvas.Select(pen_donut);
         canvas.DrawCircle(screen_center.x, screen_center.y,
-                      screen_radius - look.thick_pen.GetWidth() / 4);
+                          screen_radius - look.thick_pen.GetWidth() / 4);
       }
     }
 
@@ -193,19 +197,24 @@ private:
     if (!PreparePolygon(airspace.GetPoints()))
       return;
 
+    const AirspaceClassRendererSettings &class_settings =
+      settings.classes[airspace.GetType()];
+
     bool fill_airspace = warning_manager.HasWarning(airspace) ||
-                         warning_manager.IsInside(airspace) ||
-                         settings.classes[airspace.GetType()].fill_mode ==
-                         AirspaceClassRendererSettings::FillMode::ALL;
-    GLEnable stencil(GL_STENCIL_TEST);
+      warning_manager.IsInside(airspace) ||
+      class_settings.fill_mode ==
+      AirspaceClassRendererSettings::FillMode::ALL;
 
     if (!warning_manager.IsAcked(airspace) &&
-        settings.classes[airspace.GetType()].fill_mode !=
+        class_settings.fill_mode !=
         AirspaceClassRendererSettings::FillMode::NONE) {
+      GLEnable stencil(GL_STENCIL_TEST);
+
       if (!fill_airspace) {
         // set stencil for filling (bit 0)
         SetFillStencil();
         DrawPrepared();
+        glColorMask(GL_TRUE, GL_TRUE, GL_TRUE, GL_TRUE);
       }
 
       // fill interior without overpainting any previous outlines
@@ -219,6 +228,7 @@ private:
         // clear fill stencil (bit 0)
         ClearFillStencil();
         DrawPrepared();
+        glColorMask(GL_TRUE, GL_TRUE, GL_TRUE, GL_TRUE);
       }
     }
 
@@ -250,12 +260,11 @@ private:
       // Don't draw outlines if border_width == 0
       return false;
     else
-      canvas.Select(look.pens[type]);
+      canvas.Select(look.classes[type].border_pen);
 
     canvas.SelectHollowBrush();
 
     // set bit 1 in stencil buffer, where an outline is drawn
-    glColorMask(GL_TRUE, GL_TRUE, GL_TRUE, GL_TRUE);
     glStencilFunc(GL_ALWAYS, 3, 3);
     glStencilMask(2);
     glStencilOp(GL_KEEP, GL_KEEP, GL_REPLACE);
@@ -264,17 +273,17 @@ private:
   }
 
   void SetupInterior(const AbstractAirspace &airspace,
-                      bool check_fillstencil = false) {
+                     bool check_fillstencil = false) {
+    const AirspaceClassLook &class_look = look.classes[airspace.GetType()];
+
     // restrict drawing area and don't paint over previously drawn outlines
     if (check_fillstencil)
       glStencilFunc(GL_EQUAL, 1, 3);
     else
       glStencilFunc(GL_EQUAL, 0, 2);
     glStencilOp(GL_KEEP, GL_KEEP, GL_KEEP);
-    glColorMask(GL_TRUE, GL_TRUE, GL_TRUE, GL_TRUE);
 
-    Color color = settings.classes[airspace.GetType()].fill_color;
-    canvas.Select(Brush(color.WithAlpha(90)));
+    canvas.Select(Brush(class_look.fill_color.WithAlpha(90)));
     canvas.SelectNullPen();
   }
 
@@ -323,9 +332,8 @@ private:
     RasterPoint screen_center = projection.GeoToScreen(airspace.GetCenter());
     unsigned screen_radius = projection.GeoToScreenDistance(airspace.GetRadius());
 
-    {
+    if (!warning_manager.IsAcked(airspace) && SetupInterior(airspace)) {
       GLEnable blend(GL_BLEND);
-      SetupInterior(airspace);
       canvas.DrawCircle(screen_center.x, screen_center.y, screen_radius);
     }
 
@@ -338,13 +346,10 @@ private:
     if (!PreparePolygon(airspace.GetPoints()))
       return;
 
-    if (!warning_manager.IsAcked(airspace)) {
+    if (!warning_manager.IsAcked(airspace) && SetupInterior(airspace)) {
       // fill interior without overpainting any previous outlines
-      {
-        SetupInterior(airspace);
-        GLEnable blend(GL_BLEND);
-        DrawPrepared();
-      }
+      GLEnable blend(GL_BLEND);
+      DrawPrepared();
     }
 
     // draw outline
@@ -375,17 +380,23 @@ private:
       // Don't draw outlines if border_width == 0
       return false;
     else
-      canvas.Select(look.pens[type]);
+      canvas.Select(look.classes[type].border_pen);
 
     canvas.SelectHollowBrush();
 
     return true;
   }
 
-  void SetupInterior(const AbstractAirspace &airspace) {
-    Color color = settings.classes[airspace.GetType()].fill_color;
-    canvas.Select(Brush(color.WithAlpha(48)));
+  bool SetupInterior(const AbstractAirspace &airspace) {
+    if (settings.fill_mode == AirspaceRendererSettings::FillMode::NONE)
+      return false;
+
+    const AirspaceClassLook &class_look = look.classes[airspace.GetType()];
+
+    canvas.Select(Brush(class_look.fill_color.WithAlpha(48)));
     canvas.SelectNullPen();
+
+    return true;
   }
 };
 
@@ -399,17 +410,17 @@ private:
  * of code overhead.
  */
 class AirspaceVisitorMap final
-  : public AirspaceVisitor, public MapDrawHelper
+  : public AirspaceVisitor, public StencilMapCanvas
 {
   const AirspaceLook &look;
   const AirspaceWarningCopy &warnings;
 
 public:
-  AirspaceVisitorMap(MapDrawHelper &_helper,
+  AirspaceVisitorMap(StencilMapCanvas &_helper,
                      const AirspaceWarningCopy &_warnings,
                      const AirspaceRendererSettings &_settings,
                      const AirspaceLook &_airspace_look)
-    :MapDrawHelper(_helper),
+    :StencilMapCanvas(_helper),
      look(_airspace_look), warnings(_warnings)
   {
     switch (settings.fill_mode) {
@@ -419,6 +430,7 @@ public:
       break;
 
     case AirspaceRendererSettings::FillMode::ALL:
+    case AirspaceRendererSettings::FillMode::NONE:
       use_stencil = false;
       break;
     }
@@ -426,38 +438,29 @@ public:
 
 private:
   void VisitCircle(const AirspaceCircle &airspace) {
-    if (warnings.IsAcked(airspace))
-      return;
-
-    AirspaceClass airspace_class = airspace.GetType();
-    if (settings.classes[airspace_class].fill_mode ==
-        AirspaceClassRendererSettings::FillMode::NONE)
-      return;
-
-    BufferRenderStart();
-    SetBufferPens(airspace);
-
     RasterPoint center = proj.GeoToScreen(airspace.GetCenter());
     unsigned radius = proj.GeoToScreenDistance(airspace.GetRadius());
     DrawCircle(center, radius);
   }
 
   void VisitPolygon(const AirspacePolygon &airspace) {
-    if (warnings.IsAcked(airspace))
-      return;
-
-    AirspaceClass airspace_class = airspace.GetType();
-    if (settings.classes[airspace_class].fill_mode ==
-        AirspaceClassRendererSettings::FillMode::NONE)
-      return;
-
-    BufferRenderStart();
-    SetBufferPens(airspace);
     DrawSearchPointVector(airspace.GetPoints());
   }
 
 protected:
   virtual void Visit(const AbstractAirspace &airspace) override {
+    if (warnings.IsAcked(airspace))
+      return;
+
+    AirspaceClass airspace_class = airspace.GetType();
+    if (settings.fill_mode == AirspaceRendererSettings::FillMode::NONE ||
+        settings.classes[airspace_class].fill_mode ==
+        AirspaceClassRendererSettings::FillMode::NONE)
+      return;
+
+    Begin();
+    SetBufferPens(airspace);
+
     switch (airspace.GetShape()) {
     case AbstractAirspace::Shape::CIRCLE:
       VisitCircle((const AirspaceCircle &)airspace);
@@ -469,26 +472,21 @@ protected:
     }
   }
 
-public:
-  void DrawIntercepts() {
-    BufferRenderFinish();
-  }
-
 private:
   void SetBufferPens(const AbstractAirspace &airspace) {
     AirspaceClass airspace_class = airspace.GetType();
 
 #ifndef HAVE_HATCHED_BRUSH
-    buffer.Select(look.solid_brushes[airspace_class]);
+    buffer.Select(look.classes[airspace_class].solid_brush);
 #else /* HAVE_HATCHED_BRUSH */
 
 #ifdef HAVE_ALPHA_BLEND
     if (settings.transparency && AlphaBlendAvailable()) {
-      buffer.Select(look.solid_brushes[airspace_class]);
+      buffer.Select(look.classes[airspace_class].solid_brush);
     } else {
 #endif
       // this color is used as the black bit
-      buffer.SetTextColor(LightColor(settings.classes[airspace_class].fill_color));
+      buffer.SetTextColor(LightColor(look.classes[airspace_class].fill_color));
 
       // get brush, can be solid or a 1bpp bitmap
       buffer.Select(look.brushes[settings.classes[airspace_class].brush]);
@@ -498,6 +496,7 @@ private:
 #ifdef HAVE_ALPHA_BLEND
     }
 #endif
+#endif /* HAVE_HATCHED_BRUSH */
 
     buffer.SelectNullPen();
 
@@ -512,8 +511,6 @@ private:
         stencil.SelectHollowBrush();
       }
     }
-
-#endif /* HAVE_HATCHED_BRUSH */
   }
 };
 
@@ -546,23 +543,25 @@ protected:
       // Don't draw outlines if border_width == 0
       return false;
 
-    canvas.Select(look.pens[type]);
+    canvas.Select(look.classes[type].border_pen);
 
     return true;
   }
 
-public:
+private:
   void VisitCircle(const AirspaceCircle &airspace) {
-    if (SetupCanvas(airspace))
-      DrawCircle(airspace.GetCenter(), airspace.GetRadius());
+    DrawCircle(airspace.GetCenter(), airspace.GetRadius());
   }
 
   void VisitPolygon(const AirspacePolygon &airspace) {
-    if (SetupCanvas(airspace))
-      DrawPolygon(airspace.GetPoints());
+    DrawPolygon(airspace.GetPoints());
   }
 
+public:
   virtual void Visit(const AbstractAirspace &airspace) override {
+    if (!SetupCanvas(airspace))
+      return;
+
     switch (airspace.GetShape()) {
     case AbstractAirspace::Shape::CIRCLE:
       VisitCircle((const AirspaceCircle &)airspace);
@@ -588,36 +587,17 @@ AirspaceRenderer::DrawIntersections(Canvas &canvas,
   }
 }
 
-void
-AirspaceRenderer::Draw(Canvas &canvas,
 #ifndef ENABLE_OPENGL
-                       Canvas &buffer_canvas, Canvas &stencil_canvas,
-#endif
-                       const WindowProjection &projection,
-                       const AirspaceRendererSettings &settings,
-                       const AirspaceWarningCopy &awc,
-                       const AirspacePredicate &visible)
-{
-  if (airspaces == NULL)
-    return;
 
-#ifdef ENABLE_OPENGL
-  if (settings.fill_mode == AirspaceRendererSettings::FillMode::ALL) {
-    AirspaceFillRenderer renderer(canvas, projection, look, awc,
-                                  settings);
-    airspaces->VisitWithinRange(projection.GetGeoScreenCenter(),
-                                          projection.GetScreenDistanceMeters(),
-                                          renderer, visible);
-  } else {
-    AirspaceVisitorRenderer renderer(canvas, projection, look, awc,
-                                     settings);
-    airspaces->VisitWithinRange(projection.GetGeoScreenCenter(),
-                                          projection.GetScreenDistanceMeters(),
-                                          renderer, visible);
-  }
-#else
-  MapDrawHelper helper(canvas, buffer_canvas, stencil_canvas, projection,
-                       settings);
+inline bool
+AirspaceRenderer::DrawFill(Canvas &buffer_canvas, Canvas &stencil_canvas,
+                           const WindowProjection &projection,
+                           const AirspaceRendererSettings &settings,
+                           const AirspaceWarningCopy &awc,
+                           const AirspacePredicate &visible)
+{
+  StencilMapCanvas helper(buffer_canvas, stencil_canvas, projection,
+                          settings);
   AirspaceVisitorMap v(helper, awc, settings,
                        look);
 
@@ -628,17 +608,89 @@ AirspaceRenderer::Draw(Canvas &canvas,
                                         projection.GetScreenDistanceMeters(),
                                         v, visible);
 
-  awc.VisitWarnings(v);
-  awc.VisitInside(v);
+  return v.Commit();
+}
 
-  v.DrawIntercepts();
+inline void
+AirspaceRenderer::DrawFillCached(Canvas &canvas, Canvas &stencil_canvas,
+                                 const WindowProjection &projection,
+                                 const AirspaceRendererSettings &settings,
+                                 const AirspaceWarningCopy &awc,
+                                 const AirspacePredicate &visible)
+{
+  if (awc.GetSerial() != last_warning_serial ||
+      !fill_cache.Check(projection)) {
+    last_warning_serial = awc.GetSerial();
 
+    Canvas &buffer_canvas = fill_cache.Begin(canvas, projection);
+    if (DrawFill(buffer_canvas, stencil_canvas,
+                                projection, settings, awc, visible))
+      fill_cache.Commit(canvas, projection);
+    else
+      fill_cache.CommitEmpty();
+  }
+
+#ifdef HAVE_ALPHA_BLEND
+#ifdef HAVE_HATCHED_BRUSH
+  if (settings.transparency && AlphaBlendAvailable())
+#endif
+    fill_cache.AlphaBlendTo(canvas, projection, 60);
+#ifdef HAVE_HATCHED_BRUSH
+  else
+#endif
+#endif
+#ifdef HAVE_HATCHED_BRUSH
+    fill_cache.CopyAndTo(canvas, projection);
+#endif
+}
+
+inline void
+AirspaceRenderer::DrawOutline(Canvas &canvas,
+                              const WindowProjection &projection,
+                              const AirspaceRendererSettings &settings,
+                              const AirspacePredicate &visible) const
+{
   AirspaceOutlineRenderer outline_renderer(canvas, projection, look, settings);
   airspaces->VisitWithinRange(projection.GetGeoScreenCenter(),
                                         projection.GetScreenDistanceMeters(),
                                         outline_renderer, visible);
-  awc.VisitWarnings(outline_renderer);
-  awc.VisitInside(outline_renderer);
+}
+
+#endif
+
+void
+AirspaceRenderer::Draw(Canvas &canvas,
+#ifndef ENABLE_OPENGL
+                       Canvas &stencil_canvas,
+#endif
+                       const WindowProjection &projection,
+                       const AirspaceRendererSettings &settings,
+                       const AirspaceWarningCopy &awc,
+                       const AirspacePredicate &visible)
+{
+  if (airspaces == NULL || airspaces->IsEmpty())
+    return;
+
+#ifdef ENABLE_OPENGL
+  if (settings.fill_mode == AirspaceRendererSettings::FillMode::ALL ||
+      settings.fill_mode == AirspaceRendererSettings::FillMode::NONE) {
+    AirspaceFillRenderer renderer(canvas, projection, look, awc,
+                                  settings);
+    airspaces->VisitWithinRange(projection.GetGeoScreenCenter(),
+                                projection.GetScreenDistanceMeters(),
+                                renderer, visible);
+  } else {
+    AirspaceVisitorRenderer renderer(canvas, projection, look, awc,
+                                     settings);
+    airspaces->VisitWithinRange(projection.GetGeoScreenCenter(),
+                                projection.GetScreenDistanceMeters(),
+                                renderer, visible);
+  }
+#else
+  if (settings.fill_mode != AirspaceRendererSettings::FillMode::NONE)
+    DrawFillCached(canvas, stencil_canvas, projection, settings, awc, visible);
+
+  DrawOutline(canvas, projection, settings, visible);
 #endif
 
   intersections = awc.GetLocations();
@@ -647,7 +699,7 @@ AirspaceRenderer::Draw(Canvas &canvas,
 void
 AirspaceRenderer::Draw(Canvas &canvas,
 #ifndef ENABLE_OPENGL
-                       Canvas &buffer_canvas, Canvas &stencil_canvas,
+                       Canvas &stencil_canvas,
 #endif
                        const WindowProjection &projection,
                        const AirspaceRendererSettings &settings)
@@ -661,7 +713,7 @@ AirspaceRenderer::Draw(Canvas &canvas,
 
   Draw(canvas,
 #ifndef ENABLE_OPENGL
-       buffer_canvas, stencil_canvas,
+       stencil_canvas,
 #endif
        projection, settings, awc, AirspacePredicateTrue());
 }
@@ -669,7 +721,7 @@ AirspaceRenderer::Draw(Canvas &canvas,
 void
 AirspaceRenderer::Draw(Canvas &canvas,
 #ifndef ENABLE_OPENGL
-                       Canvas &buffer_canvas, Canvas &stencil_canvas,
+                       Canvas &stencil_canvas,
 #endif
                        const WindowProjection &projection,
                        const MoreData &basic,
@@ -684,11 +736,12 @@ AirspaceRenderer::Draw(Canvas &canvas,
   if (warning_manager != NULL)
     awc.Visit(*warning_manager);
 
+  const AircraftState aircraft = ToAircraftState(basic, calculated);
   const AirspaceMapVisible visible(computer_settings, settings,
-                                   ToAircraftState(basic, calculated), awc);
+                                   aircraft, awc);
   Draw(canvas,
 #ifndef ENABLE_OPENGL
-       buffer_canvas, stencil_canvas,
+       stencil_canvas,
 #endif
        projection, settings, awc, visible);
 }
