@@ -110,8 +110,16 @@ Replay::Update()
   if (replay == nullptr)
     return false;
 
-  if (!positive(time_scale))
+  if (!positive(time_scale)) {
+    /* replay is paused */
+    /* to avoid a big fast-forward with the next
+       PeriodClock::ElapsedUpdate() call below after unpausing, update
+       the clock each time we're called while paused */
+    clock.Update();
     return true;
+  }
+
+  const fixed old_virtual_time = virtual_time;
 
   if (!negative(virtual_time)) {
     /* update the virtual time */
@@ -160,6 +168,13 @@ Replay::Update()
 
         if (next_data.time >= virtual_time)
           break;
+
+        if (next_data.time < old_virtual_time) {
+          /* time warp; that can happen on midnight wraparound during
+             NMEA replay */
+          virtual_time = next_data.time;
+          break;
+        }
       }
     }
   } else {
@@ -224,7 +239,7 @@ Replay::OnTimer()
   else if (negative(virtual_time) || !next_data.time_available)
     schedule = 500;
   else if (cli != nullptr)
-    schedule = 500;
+    schedule = 1000;
   else {
     fixed delta_s = (next_data.time - virtual_time) / time_scale;
     int delta_ms = int(delta_s * 1000);
