@@ -38,6 +38,7 @@ int terrain_height = 1;
 std::string replay_file = "test/data/0asljd01.igc";
 std::string waypoint_file = "test/data/waypoints_geo.wpt";
 std::string task_file = "";
+fixed range_threshold = fixed(15000);
 
 #ifdef INSTRUMENT_TASK
 extern long count_mc;
@@ -129,12 +130,13 @@ ParseArgs(int argc, char** argv)
 	{"igc", required_argument,       0, 'f'},
 	{"task", required_argument,       0, 'x'},
 	{"waypoints", required_argument,       0, 'w'},
+	{"rangethreshold", required_argument,       0, 'd'},
 	{0, 0, 0, 0}
       };
     /* getopt_long stores the option index here. */
     int option_index = 0;
 
-    int c = getopt_long (argc, argv, "s:v:i:n:t:r:a:f:x:w:",
+    int c = getopt_long (argc, argv, "s:v:i:n:t:r:a:f:x:w:d:",
                          long_options, &option_index);
     /* Detect the end of the options. */
     if (c == -1)
@@ -159,6 +161,9 @@ ParseArgs(int argc, char** argv)
     case 'x':
       task_file = optarg;
       break;
+    case 'd':
+      range_threshold = (fixed)atof(optarg);
+      break;
     case 'a':
       autopilot_parms.start_alt = (fixed)atof(optarg);
       break;
